import _plotly_utils.basevalidators


class XgapValidator(_plotly_utils.basevalidators.NumberValidator):

    def __init__(
        self, plotly_name='xgap', parent_name='layout.grid', **kwargs
    ):
        super(XgapValidator, self).__init__(
            plotly_name=plotly_name,
            parent_name=parent_name,
            edit_type='plot',
            max=1,
            min=0,
            role='info',
            **kwargs
        )
